## Description

<!-- Describe your changes in detail -->

## Type of Change

<!-- Put an `x` in the boxes that apply -->

- [ ] 🐛 Bug fix (non-breaking change which fixes an issue)
- [ ] ✨ New feature (non-breaking change which adds functionality)
- [ ] 💥 Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] 📝 Documentation update
- [ ] 🎨 Style/UI update (no functional changes)
- [ ] ♻️ Code refactoring (no functional changes)
- [ ] ⚡ Performance improvement
- [ ] ✅ Test update
- [ ] 🔧 Configuration/build update

## Related Issues

<!-- Link related issues here using #issue-number -->

Fixes #
Relates to #

## Changes Made

<!-- List the specific changes made in this PR -->

-
-
-

## Testing

<!-- Describe how you tested your changes -->

- [ ] All existing tests pass (`uv run poe check`)
- [ ] Added new tests for new functionality
- [ ] Tested manually in the TUI

### Manual Testing Steps

1.
2.
3.

## Screenshots/Demo

<!-- If applicable, add screenshots or a demo of the changes -->

## Checklist

- [ ] My code follows the project's style guidelines
- [ ] I have run `uv run poe fix` to format my code
- [ ] I have performed a self-review of my code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] Any dependent changes have been merged and published

## Additional Notes

<!-- Any additional information that reviewers should know -->
